OC.L10N.register(
    "dav",
    {
    "Calendar" : "Календар",
    "Todos" : "Задачи",
    "Personal" : "Лично",
    "{actor} created calendar {calendar}" : "{actor} креираше календар {calendar}",
    "You created calendar {calendar}" : "Вие креиравте календар {calendar}",
    "{actor} deleted calendar {calendar}" : "{actor} избриша календар {calendar}",
    "You deleted calendar {calendar}" : "Вие избришавте календар {calendar}",
    "{actor} updated calendar {calendar}" : "{actor} ажурираше календар {calendar}",
    "You updated calendar {calendar}" : "Вие ажуриравте календар {calendar}",
    "You shared calendar {calendar} as public link" : "Споделивте календар {calendar} како јавен линк",
    "You removed public link for calendar {calendar}" : "Одстранивте јавен за календар {calendar}",
    "{actor} shared calendar {calendar} with you" : "{actor} сподели календар {calendar} со вас",
    "You shared calendar {calendar} with {user}" : "Вие споделивте календар {calendar} со {user}",
    "{actor} shared calendar {calendar} with {user}" : "{actor} сподели календар {calendar} со {user}",
    "{actor} unshared calendar {calendar} from you" : "{actor} го одстрани споделувањето на календар {calendar} со вас",
    "You unshared calendar {calendar} from {user}" : "Вие го одстранивте споделувањето на календар {calendar} со {user}",
    "{actor} unshared calendar {calendar} from {user}" : "{actor} го одстрани споделувањето на календар {calendar} со {user}",
    "{actor} unshared calendar {calendar} from themselves" : "{actor} го одстрани споделувањето на календар {calendar} со сите",
    "You shared calendar {calendar} with group {group}" : "Вие споделивте календар {calendar} со група {group}",
    "{actor} shared calendar {calendar} with group {group}" : "{actor} сподели календар {calendar} со група {group}",
    "You unshared calendar {calendar} from group {group}" : "Вие го одстранивте споделувањето на календар {calendar} од група {group}",
    "{actor} unshared calendar {calendar} from group {group}" : "{actor} го одстрани споделувањето на календар {calendar} од група {group}",
    "{actor} created event {event} in calendar {calendar}" : "{actor} креираше настан {event} во календар {calendar}",
    "You created event {event} in calendar {calendar}" : "Вие креиравте настан {event} во календар {calendar}",
    "{actor} deleted event {event} from calendar {calendar}" : "{actor} избриша настан {event} од календар {calendar}",
    "You deleted event {event} from calendar {calendar}" : "Вие избришавте настан {event} од календар {calendar}",
    "{actor} updated event {event} in calendar {calendar}" : "{actor} ажурирање настан {event} во календар {calendar}",
    "You updated event {event} in calendar {calendar}" : "Вие ажуриравте настан {event} во календар {calendar}",
    "Busy" : "Зафатен",
    "A <strong>calendar</strong> was modified" : "<strong>Календарот</strong> е променет",
    "A calendar <strong>event</strong> was modified" : "Изменет е <strong>настан</strong> во календарот",
    "A calendar <strong>todo</strong> was modified" : "Изменета е <strong>задача</strong> во календарот",
    "Death of %s" : "Смрт на %s",
    "Contact birthdays" : "Родендени на контактите",
    "Calendar:" : "Календар:",
    "Date:" : "Датум:",
    "Where:" : "Каде: ",
    "Description:" : "Опис:",
    "Untitled event" : "Насловен настан",
    "_%n year_::_%n years_" : ["една година","%n години"],
    "_%n month_::_%n months_" : ["еден месец","%n месеци"],
    "_%n day_::_%n days_" : ["еден ден","%n дена"],
    "_%n hour_::_%n hours_" : ["еден час","%n часа"],
    "_%n minute_::_%n minutes_" : ["една минута","%n минути"],
    "%s (in %s)" : "%s (во %s)",
    "%s (%s ago)" : "%s (пред %s)",
    "Calendar: %s" : "Календар: %s",
    "Date: %s" : "Датум: %s",
    "Description: %s" : "Опис: %s",
    "Where: %s" : "Каде: %s",
    "%1$s via %2$s" : "%1$s преку %2$s",
    "Invitation canceled" : "Поканата е откажана",
    "Hello %s," : "Здраво %s,",
    "The meeting »%1$s« with %2$s was canceled." : "Состанокот »%1$s« со %2$s е откажан.",
    "Invitation updated" : "Поканата е ажурирана",
    "The meeting »%1$s« with %2$s was updated." : "Состанокот »%1$s« со %2$s е ажуриран.",
    "%1$s invited you to »%2$s«" : "%1$s ве покани вас »%2$s«",
    "When:" : "Кога:",
    "Link:" : "Линк:",
    "Accept" : "Прифати",
    "Decline" : "Одбиј",
    "More options …" : "Повеќе опции ...",
    "More options at %s" : "Повеќе опции на %s",
    "Contacts" : "Контакти",
    "Your %s needs to be configured to use HTTPS in order to use CalDAV and CardDAV with iOS/macOS." : "Вашиот %s треба да биде конфигуриран за да користи HTTPS за да може да се користи CalDAV и CardDAV на iOS/macOS.",
    "Configures a CalDAV account" : "Конфигурирај CalDAV сметка",
    "Configures a CardDAV account" : "Конфигурирај CardDAV сметка",
    "WebDAV" : "WebDAV",
    "WebDAV endpoint" : "WebDAV крајна точка",
    "Technical details" : "Технички детали",
    "Remote Address: %s" : "Далечинкска Адреса: %s",
    "Request ID: %s" : "Барање број: %s",
    "There was an error updating your attendance status." : "Настана грешка при ажурирање на вашето присуство.",
    "Please contact the organizer directly." : "Контактирајте го организаторот директно.",
    "Are you accepting the invitation?" : "Дали ја прифаќате поканата?",
    "Tentative" : "Прелиминарен",
    "Save" : "Зачувај",
    "Your attendance was updated successfully." : "Вашето присуство е успешно ажурирано.",
    "Calendar server" : "Календар сервер",
    "Also install the {calendarappstoreopen}Calendar app{linkclose}, or {calendardocopen}connect your desktop & mobile for syncing ↗{linkclose}." : "Исто така инсталирајте ја {calendarappstoreopen}Календар апликацијата{linkclose}, или {calendardocopen}поврзете го вашиот компјутер & мобилен за синхронизација ↗{linkclose}.",
    "Send invitations to attendees" : "Испрати покани на учесниците",
    "Please make sure to properly set up {emailopen}the email server{linkclose}." : "Бидете сигурни дека правилно се поставени {emailopen}параметрите за Е-пошта{linkclose}.",
    "Automatically generate a birthday calendar" : "Автоматско генерирање на календар со родендени",
    "Birthday calendars will be generated by a background job." : "Календарот со родендени ќе се генерира преку задачите што се извршуваат во позадина.",
    "Hence they will not be available immediately after enabling but will show up after some time." : "Оттука, тие нема да бидат достапни веднаш по овозможувањето, но ќе се појават по некое време.",
    "Send notifications for events" : "Испрати известувања за настани",
    "Enable notifications for events via push" : "Овозможи известувања за настани преку push",
    "Please make sure to properly set up the email settings above." : "Бидете сигурни дека правилно се поставени параметрите за Е-пошта.",
    "Notifications will be send through background jobs, so these need to happen often enough." : "Известувањата ќе бидат испраќани преку задачите што се извршуваат во позадина, така што тие треба да се случуваат доволно често."
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
